#!/bin/sh

die_with_error() {
    if [[ $1 -ne 0 ]]; then
        echo "$2"
        echo
        echo "$3"
        exit 1
    fi
}

password="$1"
if [[ -z $password ]]; then
    password="password"
fi

mount_pt="/opt/orchid-mnt"
cd $mount_pt

# Verify bundle exists
if [[ ! -f ${mount_pt}/orchid_bundle.tar ]]; then
    echo "Could not find Orchid Core VMS ACAP bundle"
    exit 1
fi

cd $mount_pt
mkdir -p orchid-tmp
cd orchid-tmp

# Extract bundle
echo -n "Extracting Orchid Core VMS ACAP bundle ... "
ret=$( tar xf ../orchid_bundle.tar 2>&1 )
die_with_error $? "Error extracting Orchid Core VMS ACAP bundle (try re-downloading):" "$ret"
echo "done!"

# Extract debian
echo -n "Extracting Orchid Core VMS Debian package ... "
ret=$( ar -x ipc-orchid-*.deb 2>&1 )
die_with_error $? "Error extracting Orchid Core VMS Debian package (try re-downloading):" "$ret"
echo "done!"

# Extract data
echo -n "Extracting Orchid Core VMS application data ... "
ret=$( ./xz -dc data.tar.xz  2>&1 | tar x 2>&1 )
die_with_error $? "Error extracting Orchid Core VMS Debian package (try re-downloading):" "$ret"
echo "done!"

# Arrange files on SD card
echo -n "Cleaning up temporary data ... "
mv opt/ ..
mv etc/ ..
mv openvpn ../opt/orchid/bin/
mv route ../opt/orchid/bin/
mv ifconfig ../opt/orchid/bin/
mv openvpn*.service /etc/systemd/system
mkdir -p /etc/openvpn
cd ..
rm -rf orchid-tmp
echo "done!"

echo -n "Configuring Orchid Core VMS services ... "
ln -sf ${mount_pt}/opt/orchid /opt/
ln -sf ${mount_pt}/etc/sysctl.d/50-orchid.conf /etc/sysctl.d/
ln -sf ${mount_pt}/etc/systemd/system/orchid.service /etc/systemd/system/orchid.service
ln -sf ${mount_pt}/etc/systemd/system/orchid_onvif_autodiscovery.service \
    /etc/systemd/system/orchid_onvif_autodiscovery.service

mkdir -p /etc/opt
cp /opt/orchid/orchid_jemalloc.conf.default \
    /etc/opt/orchid_jemalloc.conf
cp /opt/orchid/orchid_onvif_autodiscovery.properties.default \
    /etc/opt/orchid_onvif_autodiscovery.properties
cp /opt/orchid/orchid_onvif_camera_quirks.dat.default \
    /etc/opt/orchid_onvif_camera_quirks.dat
cp /opt/orchid/orchid_server.properties.default \
    /etc/opt/orchid_server.properties

sed -i 's%^webserver.port =.*%webserver.port = 8080%' /etc/opt/orchid_server.properties
sed -i 's%^webserver.archives.rootpath =.*%webserver.archives.rootpath = /var/spool/storage/SD_DISK/orchives%' \
    /etc/opt/orchid_server.properties
sed -i 's%^archivecleaner.usedspace.percentage =.*%archivecleaner.usedspace.percentage = 97%' \
    /etc/opt/orchid_server.properties
sed -i 's%^sqlite.filepath =.*%sqlite.filepath = /var/spool/storage/SD_DISK/orchid.sqlite%' \
    /etc/opt/orchid_server.properties
sed -i 's%^logger.dir =.*%logger.dir = /var/spool/storage/SD_DISK/orchid-logs%' \
    /etc/opt/orchid_server.properties
echo "rtsp.service = 8554" >> /etc/opt/orchid_server.properties
echo "orchid.admin.password = ${password}" >> /etc/opt/orchid_server.properties

systemctl enable orchid.service > /dev/null 2>&1
systemctl enable orchid_onvif_autodiscovery.service > /dev/null 2>&1
systemctl start orchid.service > /dev/null 2>&1
systemctl start orchid_onvif_autodiscovery.service > /dev/null 2>&1
echo "done!"
