#!/bin/sh

sd_part="/dev/mmcblk0p1"
mount_pt="/opt/orchid-mnt"

disable_service() {
    service_file="$1"
    service_name="$2"

    echo -n "Stopping $service_name ... "
    systemctl disable $service_file > /dev/null 2>&1
    systemctl stop $service_file > /dev/null 2>&1
    echo "done!"
}

# Configure the SD card
if [[ ! -b $sd_part ]]; then
    echo "SD card not found at ${sd_part}"
    exit 1
fi

# Get storage-manager out of the way (temporarily)
disable_service "orchid.service" "Orchid Core VMS service"
disable_service "orchid_onvif_autodiscovery.service" "Orchid ONVIF Autodiscovery service"
disable_service "openvpn.service" "Orchid VPN service"
disable_service "storage-manager.service" "storage-manager service"

# Unmount if mounted (best effort)
echo -n "Unmounting SD card ... "
umount ${sd_part} > /dev/null 2>&1
echo "done!"

echo -n "Formatting SD card ... "
mkfs.ext4 -F -m 1 ${sd_part} > /dev/null 2>&1
echo "done!"

# Bail if the format failed
if [[ $? -ne 0 ]]; then
    echo "Failed to format SD card!"
    echo
    exit 2
fi


# Go crazy, let us execute from the SD card!
echo -n "Configure SD card to run Orchid ... "
sed -i '/^\/dev\/mmcblk0p1.*/d' /etc/fstab
echo "/dev/mmcblk0p1 ${mount_pt} auto defaults,exec,noatime,nofail 0 0" \
    >> /etc/fstab
echo "done!"

mkdir -p $mount_pt
mount $mount_pt

systemctl enable storage-manager.service > /dev/null 2>&1
systemctl start storage-manager.service > /dev/null 2>&1

sleep 1

# Verify SD card comes back
if ! /bin/mount | /bin/grep ${sd_part} | /bin/grep ${mount_pt}  > /dev/null 2>&1; then
    echo "Could not mount SD card"
    exit 3
fi
